# rHiddenFeedback() handles the \shinyRHiddenFeedback environment for innerCode()


rHiddenFeedback = function(text, inputId, options, lineNumOffset, globalInfoEnv) {
  if (inputId=="" || make.names(inputId)!=inputId) {
    stop("@ ", lineNumOffset, 
         " first argument of \\begin{shinyRHiddenFeedback} must be a valid R name (inputId)")
  }
  
  options = parseCommand(paste0("shinyRHiddenFeedback(second_curly_brace_set){", options, "}"), 
                         lineNumOffset)$options

  options = parseOptions("shinyRHiddenFeedback", options, 
                         required=NULL, requiredTypes=NULL,
                         optional=c("openLabel",
                                    "monitorAll", "monitorErrors"), 
                         optionalTypes=c("c","l","l"),
                         lineNumOffset=lineNumOffset,
                         defaults=list(openLabel="View detailed feedback",
                                       monitorAll=FALSE,
                                       monitorErrors=TRUE))
  
  # Update global info
  priorRF = getGlobal("RFeedback", globalInfoEnv)
  if (is.null(priorRF) || !any(priorRF$id == inputId)) {
    stop("\\shinyRHiddenFeedback id '",  inputId, "' @ ", lineNumOffset, " has no prior \\shinyRFeedback")
  }

  priorRHF = getGlobal("RHiddenFeedback", globalInfoEnv)
  if (is.null(priorRHF)) {
    assign("RHiddenFeedback", data.frame(id=inputId, lineNum=lineNumOffset), envir=globalInfoEnv)
  } else {
    Sel = (inputId==priorRHF$id)
    if (any(Sel)) {
      stop("\\RHiddenFeedback id '",  inputId, "' @ both ", priorRHF$lineNum[Sel], " and ", lineNumOffset)
    }
    assign("RHiddenFeedback", rbind(priorRHF, data.frame(id=inputId, lineNum=lineNumOffset)), envir=globalInfoEnv)
  }
  

  ####################### Set User Interface code for this RHiddenFeedback block ###########################
  ########## To get textEnter to respond only at Enter, go to
  ########## C:\Users\hseltman\Documents\R\win-library\3.2\shiny\www\shared
  ########## and erase "$(a).on("keyup.textInputBinding input.textInputBinding",function(a){b(!0)}),"
  uiCode = c(paste0('checkboxInput(inputId="openRHidden', inputId,'", label="', options$openLabel ,'", value=FALSE),'),
             paste0('conditionalPanel("input.openRHidden', inputId, ' == true",'),
             paste0('                 verbatimTextOutput(outputId="RHiddenOut', inputId, '")'),
             '),',
             'HTML(\'<div style="padding:1ex"></div>\'),')

    
  ## Set server code ##
  serverCode = feedbackCommon(inputId, text, isHidden=TRUE, options, lineNumOffset)
  
  return(list(uiCode=uiCode, serverCode=serverCode))
}
